(utilities-module)=
# AutoTrader Utilities Module


(utils-get-config)=
## Configuration Utilities
```{eval-rst}
.. autofunction:: autotrader.utilities.get_config
```




## YAML Utilities

### Read YAML
```{eval-rst}
.. autofunction:: autotrader.utilities.read_yaml
```


### Write YAML
```{eval-rst}
.. autofunction:: autotrader.utilities.write_yaml
```


## Watchlist Utilities
```{eval-rst}
.. autofunction:: autotrader.utilities.get_watchlist
```


(utils-datastream)=
## DataStream Class
```{eval-rst}
.. autoclass:: autotrader.utilities.DataStream
   :members:
```
